@@ -6,7 +6,7 @@ from requests import Response
 
 from gigapipe.api_client.api import Base
 from gigapipe.api_client.gigapipe_api import GigapipeApi
-from gigapipe.exceptions import GigapipeServerError
+from gigapipe.exceptions import GigapipeServerError, GigapipeClientError
 
 
 class Clusters(Base):
@@ -259,6 +259,11 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
 
     @GigapipeApi.autorefresh_access_token
@@ -280,6 +285,11 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
 
     @GigapipeApi.autorefresh_access_token
@@ -323,6 +333,11 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
 
     @GigapipeApi.autorefresh_access_token
@@ -364,6 +379,11 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
 
     @GigapipeApi.autorefresh_access_token
@@ -389,6 +409,11 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
 
     @GigapipeApi.autorefresh_access_token
@@ -417,4 +442,9 @@ class Clusters(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
