@@ -2,7 +2,7 @@ from typing import Dict
 import requests
 from http import HTTPStatus
 from requests import Response
-from gigapipe.exceptions import GigapipeServerError
+from gigapipe.exceptions import GigapipeServerError, GigapipeClientError
 from gigapipe.api_client.api import Base
 from gigapipe.api_client.gigapipe_api import GigapipeApi
 
@@ -36,4 +36,9 @@ class Roles(Base):
                 status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
                 message=f"Internal Server Error: {e}"
             )
+        except TypeError:
+            raise GigapipeClientError(
+                status_code=HTTPStatus.BAD_REQUEST,
+                message=f"Wrong Payload"
+            )
         return response
